#
# spec file for package libsysstat
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define  sover  1
Name:           libsysstat
Version:        1.0.0
Release:        1.1
Summary:        Library used to query system info and statistics
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/lxqt/libsysstat
Source0:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake >= 3.18.0
BuildRequires:  gcc-c++
BuildRequires:  cmake(Qt6LinguistTools) >= 6.6
BuildRequires:  cmake(lxqt2-build-tools) >= 2.0.0

%description
libsysstat is a library to query system information like CPU and memory
usage or network traffic. libsysstat is used by plugin-sysstat of
lxqt-panel.

%package -n %{name}%{sover}
Summary:        Libraries for lxqt
Group:          System/Libraries
Provides:       %{name}

%description -n %{name}%{sover}
Development libraries for libsysstat

%package devel
Summary:        Devel files for libsysstat
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sover} = %{version}
Requires:       pkgconfig

%description devel
sysstat libraries for development

%prep
%autosetup -p1

%build
%cmake_qt6
%{qt6_build}

%install
%{qt6_install}

%ldconfig_scriptlets -n %{name}%{sover}

%files -n %{name}%{sover}
%doc AUTHORS CHANGELOG README.md
%{_libdir}/%{name}-qt6.so.*
%license COPYING

%files devel
%{_includedir}/sysstat-qt6
%{_datadir}/cmake/sysstat-qt6
%{_libdir}/pkgconfig/sysstat-qt6.pc
%{_libdir}/%{name}-qt6.so

%changelog
* Sat May 11 2024 Андрей Алыпов <and.november@opensuse.org>
- Source upload
  Add: libsysstat.keyring
* Thu Apr 18 2024 Shawn Dunn <sfalken@opensuse.org>
- Update to 2.0.0:
  * Ported to Qt6
- Specfile Cleanup and macro updating
- Change packagename from libsysstat-qtVER
* Mon Nov  8 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.4.6:
  * Bumped minimum required Qt version to 5.15 and dropped dead code.
* Fri Apr 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.4.5:
  * Initialized some variables.
  * Used "= default" to define trivial destructors.
  * Handled Qt5.15's deprecations.
* Wed Nov  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.4.4:
  * Bumped version to 0.4.4
* Mon Apr 27 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Changed libsysstat-qt5.keyring to tsujan's key
* Sat Apr 25 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 0.4.3
  * C++11 code updates.
  * Removed (duplicated) string casts definitions.
* Tue Feb  5 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Thu Jan 31 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.4.2:
  * Improved cmake scripting and set cmake_minimum_required to 3.1.0
  * Don't use automatic string conversions
  * Removes local compile definition
* Tue May 22 2018 mvetter@suse.com
- Update to 0.4.1:
  * Bump patch version to 1
  * CMake: Prevent in-source builds
  * Fixed year and https
  * Fixes some lxde mentions
  * Drop Qt foreach.
  * Handle CMake CMP0024
  * Don't export github templates
* Mon Oct 23 2017 mvetter@suse.com
- Update to 0.4.0:
  * correct spelling mistake
  * bump version and needed version of lxqt-build-tools
  * liblxqt make no sense here
  * Copied issue template
  * Drops Qt5Core_VERSION_STRING
  * Fixes (#17)
  * Bump years
* Fri Feb 24 2017 sfalken@opensuse.org
- Update to 0.3.3:
  * Bump patch version to 3
  * Simplify include_directories and compile definitions
  * Adds Building project name and Qt version message
  * Adds a minimum Qt minimum version requirement
  * README.md: Add build dependency lxqt-build-tools
  * Use the lxqt-build-tools LXQtCreatePkgConfigFile
  * Use the lxqt-build-tools LXQtCreatePortableHeaders module
  * Use the new lxqt-build-tools package
  * Remove cpack (#14)
* Sat Sep 24 2016 mvetter@suse.com
- Update to 0.3.2:
  * rare file descriptor leak fixed
  * documentation improvements
* Thu Nov  5 2015 mvetter@suse.com
- Upstream release 0.3.1
* Mon Feb  9 2015 sfalken@opensuse.org
- new upstream version 0.3.0
* Sat Oct 25 2014 andrea@opensuse.org
- new upstream version 0.2.0
* Tue May 13 2014 andrea@opensuse.org
- spec file cleanup for factory
* Tue May 13 2014 sfalken@opensuse.org
- Specfile Cleanup
* Mon May 12 2014 sfalken@opensuse.org
- Removed fedora specfile, split into subproject
  Del: libsysstat-Fedora_20.spec
* Sat May 10 2014 sfalken@opensuse.org
- ran spec-cleaner on specfile
* Fri May  9 2014 sfalken@opensuse.org
- Added specfile for Fedora_20
  Add: libsysstat-Fedora_20.spec
* Fri May  9 2014 sfalken@opensuse.org
- Added tarball for new stable release
  Add:  libsysstat-0.1.0.tar.xz
  Del:  _service
* Wed Apr  2 2014 sfalken@opensuse.org
- Removed direct cmake calls, in favour of %%cmake and %%cmake_install
* Wed Apr  2 2014 sfalken@opensuse.org
- Initial Source Upload
  Add: _system
  Add: libsysstat.spec
  Add: libsysstat.changes
